#[non_exhaustive]pub struct As2AsyncMdnConnectorConfig {
pub url: Option<String>,
pub server_ids: Option<Vec<String>>,
}Expand description
Contains the configuration details for asynchronous Message Disposition Notification (MDN) responses in AS2 connectors. This configuration specifies where asynchronous MDN responses should be sent and which servers should handle them.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: Option<String>The URL endpoint where asynchronous MDN responses should be sent.
server_ids: Option<Vec<String>>A list of server identifiers that can handle asynchronous MDN responses. You can specify between 1 and 10 server IDs.
Implementations
Sourceimpl As2AsyncMdnConnectorConfig
impl As2AsyncMdnConnectorConfig
Sourcepub fn url(&self) -> Option<&str>
pub fn url(&self) -> Option<&str>
The URL endpoint where asynchronous MDN responses should be sent.
Sourcepub fn server_ids(&self) -> &[String]
pub fn server_ids(&self) -> &[String]
A list of server identifiers that can handle asynchronous MDN responses. You can specify between 1 and 10 server IDs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .server_ids.is_none().
Sourceimpl As2AsyncMdnConnectorConfig
impl As2AsyncMdnConnectorConfig
Sourcepub fn builder() -> As2AsyncMdnConnectorConfigBuilder
pub fn builder() -> As2AsyncMdnConnectorConfigBuilder
Creates a new builder-style object to manufacture As2AsyncMdnConnectorConfig.